powered by
Obtain indices for splitting observations into \(K\) blocks to be to be folded into training and test data during \(K\)-fold cross-validation.
cv_folds(n, K = 5L)
A list of indices giving the blocks of observations to be folded into training and test data during cross-validation.
an integer giving the number of observations to be split.
an integer giving the number of blocks into which the observations should be split (the default is five).
Andreas Alfons
cggm_cv()
cv_folds(20, K = 5)
Run the code above in your browser using DataLab